pub struct InputAtom<M>where
M: MessageRetriever,{ /* private fields */ }Expand description
Atom that retrieves user input for a turn
This atom:
- Retrieves the user message from the message retriever using input_message_id
- Returns the message for downstream processing
The message is expected to already be stored by the API layer (which emits input.message). This atom just retrieves it and prepares for the turn.
Implementations
Sourceimpl<M> InputAtom<M>
impl<M> InputAtom<M>
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
Stable phase name used by logs and durable activity adapters.
Sourcepub async fn execute(
&self,
input: InputAtomInput,
) -> Result<InputAtomResult, AgentLoopError>
pub async fn execute( &self, input: InputAtomInput, ) -> Result<InputAtomResult, AgentLoopError>
Retrieve the turn’s already-persisted input message.