pub struct InputAtom<M>where
M: MessageRetriever,{ /* private fields */ }Expand description
Atom that retrieves user input for a turn
This atom:
- Retrieves the user message from the message retriever using input_message_id
- Returns the message for downstream processing
The message is expected to already be stored by the API layer (which emits input.message). This atom just retrieves it and prepares for the turn.
Implementations